.. _tutorial_section:

===========
Tutorials
===========

Some of the tutorials are also available in the
`zfit youtube channel <https://www.youtube.com/channel/UC_IOWLYdQSkWr54K-o8BTCA>`_


Tutorials on zfit
=====================

For a simple introduction to zfit, see also the section :ref:`5-minutes-to-zfit`


.. toctree::
    :maxdepth: 2

    introduction
    components/index
    statistics/index
    guides/index

To start out, there are :ref:`example-scripts`
